Skip to contents

Runs a bundled Shiny interface for uploading a non-sensitive long-format CSV, validating and classifying responses, viewing issues and a profile plot, and exporting classified data.

Usage

pcat_app()

Details

The application is an analysis interface, not a secure survey-collection platform. Do not upload protected health information or sensitive direct identifiers.

Value

The value returned by shiny::runApp().

Examples

if (FALSE) { # \dontrun{
pcat_app()
} # }